<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Mezze Pro
 * @since Mezze Pro 1.0.0
 */

if ( ! function_exists( 'mezze_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Mezze Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function mezze_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'mezze_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'mezze_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Mezze Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function mezze_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'mezze_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'mezze_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Mezze Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function mezze_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'mezze_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mezze_pro_theme_options[topbar_section_enable]' )->value() );
}

/**
 * Check if slider section is enabled.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mezze_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[slider_content_type]' )->value();
	return mezze_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[slider_content_type]' )->value();
	return mezze_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[slider_content_type]' )->value();
	return mezze_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is product.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_slider_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[slider_content_type]' )->value();
	return mezze_pro_is_slider_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if slider section content type is product category.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_slider_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[slider_content_type]' )->value();
	return mezze_pro_is_slider_section_enable( $control ) && ( 'product-category' == $content_type );
}


/**
 * Check if about section is enabled.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mezze_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[about_content_type]' )->value();
	return mezze_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[about_content_type]' )->value();
	return mezze_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[about_content_type]' )->value();
	return mezze_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if special menu section is enabled.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_special_menu_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mezze_pro_theme_options[special_menu_section_enable]' )->value() );
}

/**
 * Check if special menu section content type is post.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_special_menu_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[special_menu_content_type]' )->value();
	return mezze_pro_is_special_menu_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if special menu section seperator.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_special_menu_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[special_menu_content_type]' )->value();
	return mezze_pro_is_special_menu_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if special menu section content type is page.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_special_menu_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[special_menu_content_type]' )->value();
	return mezze_pro_is_special_menu_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if special menu section content type is category.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_special_menu_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[special_menu_content_type]' )->value();
	return mezze_pro_is_special_menu_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if special menu section content type is product.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_special_menu_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[special_menu_content_type]' )->value();
	return mezze_pro_is_special_menu_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if special menu section content type is product category.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_special_menu_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[special_menu_content_type]' )->value();
	return mezze_pro_is_special_menu_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if author choice section is enabled.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_author_choice_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mezze_pro_theme_options[author_choice_section_enable]' )->value() );
}

/**
 * Check if author choice section content type is post.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_author_choice_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[author_choice_content_type]' )->value();
	return mezze_pro_is_author_choice_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if author choice section seperator.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_author_choice_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[author_choice_content_type]' )->value();
	return mezze_pro_is_author_choice_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if author choice section content type is page.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_author_choice_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[author_choice_content_type]' )->value();
	return mezze_pro_is_author_choice_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if author choice section content type is category.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_author_choice_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[author_choice_content_type]' )->value();
	return mezze_pro_is_author_choice_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if author choice section content type is product.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_author_choice_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[author_choice_content_type]' )->value();
	return mezze_pro_is_author_choice_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if author choice section content type is product category.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_author_choice_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[author_choice_content_type]' )->value();
	return mezze_pro_is_author_choice_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mezze_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is post.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[service_content_type]' )->value();
	return mezze_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[service_content_type]' )->value();
	return mezze_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if service section content type is page.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[service_content_type]' )->value();
	return mezze_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[service_content_type]' )->value();
	return mezze_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mezze_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section seperator.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_testimonial_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[testimonial_content_type]' )->value();
	return mezze_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[testimonial_content_type]' )->value();
	return mezze_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[testimonial_content_type]' )->value();
	return mezze_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[testimonial_content_type]' )->value();
	return mezze_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is position.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_testimonial_section_content_position_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[testimonial_content_type]' )->value();
	return mezze_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[testimonial_content_type]' )->value();
	return mezze_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if special offer section is enabled.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_special_offer_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mezze_pro_theme_options[special_offer_section_enable]' )->value() );
}

/**
 * Check if special offer section content type is post.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_special_offer_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[special_offer_content_type]' )->value();
	return mezze_pro_is_special_offer_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if special offer section content type is page.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_special_offer_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[special_offer_content_type]' )->value();
	return mezze_pro_is_special_offer_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if special offer section content type is category.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_special_offer_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[special_offer_content_type]' )->value();
	return mezze_pro_is_special_offer_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if special offer section content type is product.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_special_offer_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[special_offer_content_type]' )->value();
	return mezze_pro_is_special_offer_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if special offer section content type is product category.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_special_offer_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[special_offer_content_type]' )->value();
	return mezze_pro_is_special_offer_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mezze_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[blog_content_type]' )->value();
	return mezze_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[blog_content_type]' )->value();
	return mezze_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[blog_content_type]' )->value();
	return mezze_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Mezze Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_pro_theme_options[blog_content_type]' )->value();
	return mezze_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}
