<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Mezze Pro
 * @since Mezze Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function mezze_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'mezze-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function mezze_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'mezze-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of products for post choices.
 * @return Array Array of post ids and name.
 */
function mezze_pro_product_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'product' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'mezze-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'mezze_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function mezze_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'mezze-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'mezze-pro' ),
            'header-font-2'   => esc_html__( 'Cherry Swash', 'mezze-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'mezze-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'mezze-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'mezze-pro' ),
        );

        $output = apply_filters( 'mezze_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'mezze_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function mezze_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'mezze-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'mezze-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'mezze-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'mezze-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'mezze-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'mezze-pro' ),
        );

        $output = apply_filters( 'mezze_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'mezze_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function mezze_pro_site_layout() {
        $mezze_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'mezze_pro_site_layout', $mezze_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'mezze_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function mezze_pro_selected_sidebar() {
        $mezze_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'mezze-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'mezze-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'mezze-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'mezze-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'mezze-pro' ),
        );

        $output = apply_filters( 'mezze_pro_selected_sidebar', $mezze_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'mezze_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function mezze_pro_global_sidebar_position() {
        $mezze_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'mezze_pro_global_sidebar_position', $mezze_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'mezze_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function mezze_pro_sidebar_position() {
        $mezze_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'mezze_pro_sidebar_position', $mezze_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'mezze_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function mezze_pro_pagination_options() {
        $mezze_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'mezze-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'mezze-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'mezze-pro' ),
        );

        $output = apply_filters( 'mezze_pro_pagination_options', $mezze_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'mezze_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function mezze_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'mezze-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'mezze-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'mezze-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'mezze-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'mezze-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'mezze-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'mezze-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'mezze-pro' ),
        );
        return apply_filters( 'mezze_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'mezze_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function mezze_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'mezze-pro' ),
            'off'       => esc_html__( 'Disable', 'mezze-pro' )
        );
        return apply_filters( 'mezze_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'mezze_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function mezze_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'mezze-pro' ),
            'off'       => esc_html__( 'No', 'mezze-pro' )
        );
        return apply_filters( 'mezze_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'mezze_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function mezze_pro_sortable_sections() {
        $sections = array(
            'slider'    => esc_html__( 'Main Slider', 'mezze-pro' ),
            'about'     => esc_html__( 'About Us', 'mezze-pro' ),
            'special_menu' => esc_html__( 'Special Menu', 'mezze-pro' ),
            'author_choice'   => esc_html__( 'Author Choice', 'mezze-pro' ),
            'service'   => esc_html__( 'Services', 'mezze-pro' ),
            'testimonial' => esc_html__( 'Testimonial', 'mezze-pro' ),
            'special_offer' => esc_html__( 'Special Offer', 'mezze-pro' ),
            'blog'      => esc_html__( 'Blog', 'mezze-pro' ),
        );
        return apply_filters( 'mezze_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'mezze_pro_slider_content_type' ) ) :
    /**
     * Slider Options
     * @return array site slider options
     */
    function mezze_pro_slider_content_type() {
        $mezze_pro_slider_content_type = array(
            'page'      => esc_html__( 'Page', 'mezze-pro' ),
            'post'      => esc_html__( 'Post', 'mezze-pro' ),
            'category'  => esc_html__( 'Category', 'mezze-pro' ),
        );

        if ( class_exists( 'WooCommerce' ) ) {
            $mezze_pro_slider_content_type = array_merge( $mezze_pro_slider_content_type, array(
                'product'   => esc_html__( 'Product', 'mezze-pro' ),
                'product-category'   => esc_html__( 'Product Category', 'mezze-pro' ),
                ) );
        }

        $output = apply_filters( 'mezze_pro_slider_content_type', $mezze_pro_slider_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'mezze_pro_special_offer_content_type' ) ) :
    /**
     * Special Offer Options
     * @return array site special_offer options
     */
    function mezze_pro_special_offer_content_type() {
        $mezze_pro_special_offer_content_type = array(
            'page'      => esc_html__( 'Page', 'mezze-pro' ),
            'post'      => esc_html__( 'Post', 'mezze-pro' ),
            'category'  => esc_html__( 'Category', 'mezze-pro' ),
        );

        if ( class_exists( 'WooCommerce' ) ) {
            $mezze_pro_special_offer_content_type = array_merge( $mezze_pro_special_offer_content_type, array(
                'product'   => esc_html__( 'Product', 'mezze-pro' ),
                'product-category'   => esc_html__( 'Product Category', 'mezze-pro' ),
                ) );
        }

        $output = apply_filters( 'mezze_pro_special_offer_content_type', $mezze_pro_special_offer_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'mezze_pro_author_choice_content_type' ) ) :
    /**
     * Author Choice Options
     * @return array site author_choice options
     */
    function mezze_pro_author_choice_content_type() {
        $mezze_pro_author_choice_content_type = array(
            'page'      => esc_html__( 'Page', 'mezze-pro' ),
            'post'      => esc_html__( 'Post', 'mezze-pro' ),
            'category'  => esc_html__( 'Category', 'mezze-pro' ),
        );

        if ( class_exists( 'WooCommerce' ) ) {
            $mezze_pro_author_choice_content_type = array_merge( $mezze_pro_author_choice_content_type, array(
                'product'   => esc_html__( 'Product', 'mezze-pro' ),
                'product-category'   => esc_html__( 'Product Category', 'mezze-pro' ),
                ) );
        }

        $output = apply_filters( 'mezze_pro_author_choice_content_type', $mezze_pro_author_choice_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'mezze_pro_special_menu_content_type' ) ) :
    /**
     * Special Menu Options
     * @return array site special menu options
     */
    function mezze_pro_special_menu_content_type() {
        $mezze_pro_special_menu_content_type = array(
            'page'      => esc_html__( 'Page', 'mezze-pro' ),
            'post'      => esc_html__( 'Post', 'mezze-pro' ),
            'category'  => esc_html__( 'Category', 'mezze-pro' ),
        );

        if ( class_exists( 'WooCommerce' ) ) {
            $mezze_pro_special_menu_content_type = array_merge( $mezze_pro_special_menu_content_type, array(
                'product'   => esc_html__( 'Product', 'mezze-pro' ),
                'product-category'   => esc_html__( 'Product Category', 'mezze-pro' ),
                ) );
        }

        $output = apply_filters( 'mezze_pro_special_menu_content_type', $mezze_pro_special_menu_content_type );


        return $output;
    }
endif;
