<?php
/**
 * Special Offer section
 *
 * This is the template for the content of special offer section
 *
 * @package Theme Palace
 * @subpackage Mezze Pro
 * @since Mezze Pro 1.0.0
 */
if ( ! function_exists( 'mezze_pro_add_special_offer_section' ) ) :
    /**
    * Add special offer section
    *
    *@since Mezze Pro 1.0.0
    */
    function mezze_pro_add_special_offer_section() {
    	$options = mezze_pro_get_theme_options();
        // Check if special offer is enabled on frontpage
        $special_offer_enable = apply_filters( 'mezze_pro_section_status', true, 'special_offer_section_enable' );

        if ( true !== $special_offer_enable ) {
            return false;
        }
        // Get special offer section details
        $section_details = array();
        $section_details = apply_filters( 'mezze_pro_filter_special_offer_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render special offer section now.
        mezze_pro_render_special_offer_section( $section_details );
    }
endif;

if ( ! function_exists( 'mezze_pro_get_special_offer_section_details' ) ) :
    /**
    * special offer section details.
    *
    * @since Mezze Pro 1.0.0
    * @param array $input special offer section details.
    */
    function mezze_pro_get_special_offer_section_details( $input ) {
        $options = mezze_pro_get_theme_options();

        // Content type.
        $special_offer_content_type  = $options['special_offer_content_type'];
        $special_offer_count = ! empty( $options['special_offer_count'] ) ? $options['special_offer_count'] : 3;

        $content = array();
        switch ( $special_offer_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $special_offer_count; $i++ ) {
                    if ( ! empty( $options['special_offer_content_page_' . $i] ) )
                        $page_ids[] = $options['special_offer_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $special_offer_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $special_offer_count; $i++ ) {
                    if ( ! empty( $options['special_offer_content_post_' . $i] ) )
                        $post_ids[] = $options['special_offer_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $special_offer_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['special_offer_content_category'] ) ? $options['special_offer_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $special_offer_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $special_offer_count; $i++ ) {
                    if ( ! empty( $options['special_offer_content_product_' . $i] ) )
                        $page_ids[] = $options['special_offer_content_product_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $special_offer_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'product-category':
                $cat_id = ! empty( $options['special_offer_content_product_category'] ) ? $options['special_offer_content_product_category'] : '';
                $args = array(
                    'post_type'      => 'product',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'product_cat',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $special_offer_count ),
                    );                    
            break;

            default:
            break;
        }

        if ( 'custom' !== $special_offer_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = mezze_pro_trim_content( 45 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// special offer section content details.
add_filter( 'mezze_pro_filter_special_offer_section_details', 'mezze_pro_get_special_offer_section_details' );


if ( ! function_exists( 'mezze_pro_render_special_offer_section' ) ) :
  /**
   * Start special offer section
   *
   * @return string special offer content
   * @since Mezze Pro 1.0.0
   *
   */
   function mezze_pro_render_special_offer_section( $content_details = array() ) {
        $options = mezze_pro_get_theme_options();
        $special_offer_content_type  = $options['special_offer_content_type'];
        $background = ! empty( $options['special_offer_image'] ) ? $options['special_offer_image'] : get_template_directory_uri() . '/assets/uploads/special-discount.jpg';
        $readmore = ! empty( $options['special_offer_btn_title'] ) ? $options['special_offer_btn_title'] : esc_html__( 'Add to Cart', 'mezze-pro' );

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="special-offer" class="relative page-section" style="background-image: url('<?php echo esc_url( $background ); ?>');">
            <div class="wrapper">
                <div class="special-offer-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":false, "autoplay": false, "draggable": true, "fade": true }'>
                    <?php foreach ( $content_details as $content ) : ?>
                        <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->
                            <?php endif; ?>

                            <div class="entry-container">
                                <?php if ( ! empty( $options['special_offer_subtitle'] ) ) : ?>
                                    <p class="section-subtitle"><?php echo esc_html( $options['special_offer_subtitle'] ); ?></p>
                                <?php endif; ?>

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->
                            
                                <?php if ( in_array( $special_offer_content_type, array( 'product', 'product-category' ) ) ) : ?>
                                    <span class="price">
                                        <?php  
                                            $product = new WC_Product( $content['id'] );
                                            echo $product->get_price_html();
                                        ?>
                                    </span><!-- .price -->
                                <?php endif; ?>

                                <div class="read-more">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-fill"><?php echo esc_html( $readmore ); ?></a>
                                </div><!-- .read-more -->
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- .special-offer-slider -->
            </div><!-- .wrapper -->
        </div><!-- #special-offer -->

    <?php }
endif;